@@ -70,33 +70,40 @@ gconf_search_dialog_search (GtkWidget *button, GConfSearchDialog *dialog)
 	GConfEditorWindow *window;
 	GdkCursor *cursor;
 
-	const gchar *pattern;
+	gchar *pattern;
 	int res;
 	
 	window = g_object_get_data (G_OBJECT (dialog), "editor-window");
 	gedit_output_window_clear (GEDIT_OUTPUT_WINDOW (window->output_window));
 	window->output_window_type = GCONF_EDITOR_WINDOW_OUTPUT_WINDOW_SEARCH;
 
-	pattern = gtk_entry_get_text (GTK_ENTRY (dialog->entry));
+	pattern = g_strdup (gtk_entry_get_text (GTK_ENTRY (dialog->entry)));
 
 	cursor = gdk_cursor_new (GDK_WATCH);
 	gdk_window_set_cursor (GTK_WIDGET (dialog)->window, cursor);
 	gdk_cursor_unref (cursor);
 	gdk_display_flush (gtk_widget_get_display (GTK_WIDGET (dialog)));
 
+	g_object_add_weak_pointer (G_OBJECT (dialog), (gpointer)&dialog);
+
 	res = gconf_tree_model_build_match_list  (GCONF_TREE_MODEL (window->tree_model),
 						  GEDIT_OUTPUT_WINDOW (window->output_window), 
 						  pattern,
 						  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->search_in_keys)),
-						  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->search_in_values)));
+						  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->search_in_values)),
+						  G_OBJECT (dialog));
 
-	gdk_window_set_cursor (GTK_WIDGET (dialog)->window, NULL);
-	gdk_display_flush (gtk_widget_get_display (GTK_WIDGET (dialog)));
+	g_free (pattern);
 
-	if (res != 0) {
-		gtk_widget_destroy (GTK_WIDGET (dialog));
-	} else {
-		gconf_search_not_found_dialog(window);
+	if (dialog != NULL) {
+		gdk_window_set_cursor (GTK_WIDGET (dialog)->window, NULL);
+		gdk_display_flush (gtk_widget_get_display (GTK_WIDGET (dialog)));
+
+		if (res != 0) {
+			gtk_widget_destroy (GTK_WIDGET (dialog));
+		} else {
+			gconf_search_not_found_dialog(window);
+		}
 	}
 }
 
@@ -122,10 +129,12 @@ gconf_search_dialog_init (GConfSearchDialog *dialog)
 
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
 	
-	hbox = gtk_hbox_new (FALSE, 8);
-	vbox = gtk_vbox_new (FALSE, 8);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 8);
+	hbox = gtk_hbox_new (FALSE, 12);
+	vbox = gtk_vbox_new (FALSE, 6);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 
@@ -133,11 +142,12 @@ gconf_search_dialog_init (GConfSearchDialog *dialog)
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Find"));
 
-	label = gtk_label_new (_("Search for: "));
+	label = gtk_label_new_with_mnemonic (_("_Search for: "));
 			
 	dialog->entry = gtk_entry_new ();
 	g_signal_connect (dialog->entry, "changed",
 			  G_CALLBACK (gconf_search_entry_changed), dialog);
+	gtk_label_set_mnemonic_widget (GTK_LABEL(label), GTK_WIDGET(dialog->entry));
 	
 	dialog->search_button = gtk_button_new_from_stock (GTK_STOCK_FIND);
 	gtk_widget_set_sensitive (dialog->search_button, FALSE);
@@ -151,7 +161,7 @@ gconf_search_dialog_init (GConfSearchDialog *dialog)
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), dialog->entry, FALSE, FALSE, 0);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
 
 	dialog->search_in_keys = gtk_check_button_new_with_mnemonic (_("Search also in key _names"));
 	gtk_box_pack_start (GTK_BOX (vbox), dialog->search_in_keys, TRUE, TRUE, 0);
